==> haskell-rfc5051-0.1.0.3-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-rfc5051.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rfc5051
version: 0.1.0.3
id: rfc5051-0.1.0.3-EliJuivYSa1Fvy6fXvUfdC
key: rfc5051-0.1.0.3-EliJuivYSa1Fvy6fXvUfdC
license: BSD-3-Clause
copyright: (C) 2013 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
synopsis: Simple unicode collation as per RFC5051.
description:
    This library implements @i;unicode-casemap@,
    the simple, non locale-sensitive unicode collation
    algorithm described in RFC 5051 (<http://www.rfc-editor.org/rfc/rfc5051.txt>).
    Proper unicode collation can be done using text-icu, but that is a big
    dependency that depends on a large C library, and rfc5051 might be better
    for some purposes.
    .
    Here is a list of strings sorted by the Prelude'\''s @sort@ function:
    .
    @Abe Oeb abe ab&#233; oeb &#193;be &#196;be &#212;eb &#225;be &#228;be &#244;eb@
    .
    Here is the same list sorted by @sortBy compareUnicode@:
    .
    @Abe abe ab&#233; &#193;be &#225;be &#196;be &#228;be Oeb oeb &#212;eb &#244;eb@
category: Text
abi: d85054694c7a99561bcb89579f21c273
exposed: True
exposed-modules:
    Data.RFC5051
hidden-modules: Data.RFC5051.UnicodeData Data.RFC5051.Types
import-dirs: /usr/lib/ghc-8.4.3/site-local/rfc5051-0.1.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/rfc5051-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/rfc5051-0.1.0.3
hs-libraries: HSrfc5051-0.1.0.3-EliJuivYSa1Fvy6fXvUfdC
depends:
    base-4.11.1.0 containers-0.5.11.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-rfc5051/html/rfc5051.haddock
haddock-html: /usr/share/doc/haskell-rfc5051/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rfc5051-0.1.0.4-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-rfc5051.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rfc5051
version: 0.1.0.4
id: rfc5051-0.1.0.4-5nyqw29SYpv4nXx9Lc9Kmu
key: rfc5051-0.1.0.4-5nyqw29SYpv4nXx9Lc9Kmu
license: BSD-3-Clause
copyright: (C) 2013 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
synopsis: Simple unicode collation as per RFC5051.
description:
    This library implements @i;unicode-casemap@,
    the simple, non locale-sensitive unicode collation
    algorithm described in RFC 5051 (<http://www.rfc-editor.org/rfc/rfc5051.txt>).
    Proper unicode collation can be done using text-icu, but that is a big
    dependency that depends on a large C library, and rfc5051 might be better
    for some purposes.
    .
    Here is a list of strings sorted by the Prelude'\''s @sort@ function:
    @Abe Oeb abe ab&#233; oeb &#193;be &#196;be &#212;eb &#225;be &#228;be &#244;eb@.
    .
    Here is the same list sorted by @sortBy compareUnicode@:
    .
    @Abe abe ab&#233; &#193;be &#225;be &#196;be &#228;be Oeb oeb &#212;eb &#244;eb@
category: Text
abi: a123ca37421f630fda8fccdef1c95f9a
exposed: True
exposed-modules:
    Data.RFC5051
hidden-modules: Data.RFC5051.UnicodeData Data.RFC5051.Types
import-dirs: /usr/lib/ghc-8.6.1/site-local/rfc5051-0.1.0.4
library-dirs: /usr/lib/ghc-8.6.1/site-local/rfc5051-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/rfc5051-0.1.0.4
hs-libraries: HSrfc5051-0.1.0.4-5nyqw29SYpv4nXx9Lc9Kmu
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
haddock-interfaces: /usr/share/doc/haskell-rfc5051/html/rfc5051.haddock
haddock-html: /usr/share/doc/haskell-rfc5051/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
